# CoreX storage - minio

This package provides an implementation of the CoreX storage interface for minio.

## Installation
~~~bash
pip install corex-storage-minio
~~~

## Usage
~~~python
from corex_storage_minio.handler import MinioHandler
handler = MinioHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
